package
Version:
v0.0.0-...-9e146bd
Opens a new window with list of versions in this module.
Published: Apr 19, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FileServerHeader struct {
}
FileServerHeader defines the binary envelope for the qsend protocol.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.